==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ColorPreferences/ts/ColorPreferences_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>ColorPreferences</name>
    <message>
        <location filename="../ColorPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Graafinen näkymä</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Colors</source>
        <translation>Värit</translation>
    </message>
</context>
<context>
    <name>GraphicsViewColors</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Graphics View</source>
        <translation>Graafinen näkymä</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Background:</source>
        <translation>Tausta:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Cursor</source>
        <translation>Kohdistin</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Crosshairs:</source>
        <translation>Ristikko:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Inactive crosshairs:</source>
        <translation>Epäaktiivi kohdistusristikko:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Origin</source>
        <translation>Alkuperä</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Relative zero:</source>
        <translation>Suhteessa nollaan:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Grid</source>
        <translation>Ristikko</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Meta grid:</source>
        <translation>Meta/kuvaus ristikko:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection</source>
        <translation>Valinta</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Primary selection color:</source>
        <translation>Ensisijainen värivalinta:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Use secondary selection color</source>
        <translation>Käytä toissijaista värivalintaa</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Secondary selection color:</source>
        <translation>Toissijainen värivalinta:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Draggable reference points:</source>
        <translation>Vedettävät vertailupisteet:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Secondary reference points:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection box border:</source>
        <translation>Valintalaatikon reuna:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Selection box fill:</source>
        <translation>Valintalaatikon täyttö:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Cross-selection box fill:</source>
        <translation>Ristivalintalaatikon täyttö:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Snap Tools</source>
        <translation>Poimintatyökalut</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Snap label:</source>
        <translation>Poiminnan selite:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Info Tools</source>
        <translation>Tieto työkalut</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Measurements and labels:</source>
        <translation>Mitat ja selitteet:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Drawing Tools</source>
        <translation>Piirrostyökalut</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Auxiliary shapes:</source>
        <translation>Ylimääräiset muodot:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Zoom Tools</source>
        <translation>Suurennustyökalut</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Zoom box border:</source>
        <translation>Suurenna/säädä laatikon reuna:</translation>
    </message>
    <message>
        <location line="-562"/>
        <source>Origin:</source>
        <translation>Nollakohta:</translation>
    </message>
    <message>
        <source>Relative Zero:</source>
        <translation type="vanished">Suhteellinen nolla:</translation>
    </message>
    <message>
        <source>Reference Point:</source>
        <translation type="vanished">Viitepiste:</translation>
    </message>
    <message>
        <location line="+81"/>
        <source>Grid:</source>
        <translation>Ruudukko:</translation>
    </message>
    <message>
        <source>Zoom Box:</source>
        <translation type="vanished">Suurennuslaatikko:</translation>
    </message>
    <message>
        <source>Selection:</source>
        <translation type="vanished">Valinta:</translation>
    </message>
    <message>
        <source>Selection Box Border:</source>
        <translation type="vanished">Valintalaatikon reuna:</translation>
    </message>
    <message>
        <source>Selection Box:</source>
        <translation type="vanished">Valintalaatikko:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ColorPreferences/ts/ColorPreferences_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>ColorPreferences</name>
    <message>
        <location filename="../ColorPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Graafinen näkymä</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Colors</source>
        <translation>Värit</translation>
    </message>
</context>
<context>
    <name>GraphicsViewColors</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Graphics View</source>
        <translation>Graafinen näkymä</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Background:</source>
        <translation>Tausta:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Cursor</source>
        <translation>Kohdistin</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Crosshairs:</source>
        <translation>Ristikko:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Inactive crosshairs:</source>
        <translation>Epäaktiivi kohdistusristikko:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Origin</source>
        <translation>Alkuperä</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Relative zero:</source>
        <translation>Suhteessa nollaan:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Grid</source>
        <translation>Ristikko</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Meta grid:</source>
        <translation>Meta/kuvaus ristikko:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection</source>
        <translation>Valinta</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Primary selection color:</source>
        <translation>Ensisijainen värivalinta:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Use secondary selection color</source>
        <translation>Käytä toissijaista värivalintaa</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Secondary selection color:</source>
        <translation>Toissijainen värivalinta:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Draggable reference points:</source>
        <translation>Vedettävät vertailupisteet:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Secondary reference points:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection box border:</source>
        <translation>Valintalaatikon reuna:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Selection box fill:</source>
        <translation>Valintalaatikon täyttö:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Cross-selection box fill:</source>
        <translation>Ristivalintalaatikon täyttö:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Start points:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>End points:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+50"/>
        <source>Snap Tools</source>
        <translation>Poimintatyökalut</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Snap label:</source>
        <translation>Poiminnan selite:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Info Tools</source>
        <translation>Tieto työkalut</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Measurements and labels:</source>
        <translation>Mitat ja selitteet:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Drawing Tools</source>
        <translation>Piirrostyökalut</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Auxiliary shapes:</source>
        <translation>Ylimääräiset muodot:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Zoom Tools</source>
        <translation>Suurennustyökalut</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Zoom box border:</source>
        <translation>Suurenna/säädä laatikon reuna:</translation>
    </message>
    <message>
        <location line="-616"/>
        <source>Origin:</source>
        <translation>Nollakohta:</translation>
    </message>
    <message>
        <source>Relative Zero:</source>
        <translation type="vanished">Suhteellinen nolla:</translation>
    </message>
    <message>
        <source>Reference Point:</source>
        <translation type="vanished">Viitepiste:</translation>
    </message>
    <message>
        <location line="+81"/>
        <source>Grid:</source>
        <translation>Ruudukko:</translation>
    </message>
    <message>
        <source>Zoom Box:</source>
        <translation type="vanished">Suurennuslaatikko:</translation>
    </message>
    <message>
        <source>Selection:</source>
        <translation type="vanished">Valinta:</translation>
    </message>
    <message>
        <source>Selection Box Border:</source>
        <translation type="vanished">Valintalaatikon reuna:</translation>
    </message>
    <message>
        <source>Selection Box:</source>
        <translation type="vanished">Valintalaatikko:</translation>
    </message>
</context>
</TS>
